@@ -4,25 +4,33 @@ use strict;
 use Socket;
 use base 'Exporter';
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 our @EXPORT_OK = 'connect';
 
 sub import
 {
-	my $pkg = shift;
+	my $mypkg = shift;
 	
-	while(my ($module, $cfg) = splice @_, 0, 2) {
+	while(my ($pkg, $cfg) = splice @_, 0, 2) {
 		unless(defined $cfg) {
-			$cfg = $module;
-			$module = undef;
+			$cfg = $pkg;
+			$pkg = undef;
 		}
 		
-		if($module) {
+		if($pkg) {
+			no strict 'refs';
 			# override connect() in the package
-			eval "require $module" # make @ISA available
-				or die $@;
 			
-			if($module->isa('IO::Socket::INET')) {
+			# do not load module with package if package already available
+			# some packages haven't separate modules
+			# so, in this case loading will fail
+			# allow the user to load correct module with needed package
+			unless(%{$pkg.'::'}) {
+				eval "require $pkg" # make @ISA available
+					or die $@;
+			}
+			
+			if($pkg->isa('IO::Socket::INET')) {
 				# replace IO::Socket::INET::connect
 				# if package inherits from IO::Socket::INET
 				*connect = sub(*$) {
@@ -32,11 +40,10 @@ sub import
 					
 					my $self = shift;
 					my $ref = ref($self);
-					no strict 'refs';
 					
 					# get first parent which has connect sub
 					# and call it
-					foreach my $parent (@{$module.'::ISA'}) {
+					foreach my $parent (@{$pkg.'::ISA'}) {
 						if($parent->isa('IO::Socket::INET')) {
 							bless $self, $parent;
 							$self->connect(@_);
@@ -53,7 +60,7 @@ sub import
 				}
 			}
 			
-			$pkg->export($module, 'connect');
+			$mypkg->export($pkg, 'connect');
 		}
 		else {
 			# override connect() globally
@@ -61,7 +68,7 @@ sub import
 				_connect(@_, $cfg);
 			};
 			
-			$pkg->export('CORE::GLOBAL', 'connect');
+			$mypkg->export('CORE::GLOBAL', 'connect');
 		}
 	}
 }
@@ -97,7 +104,7 @@ __END__
 
 =head1 NAME
 
-IO::Socket::Socks::Wrapper - Allow any perl module to work through a socks proxy
+IO::Socket::Socks::Wrapper - Allow any perl package to work through a socks proxy
 
 =head1 SYNOPSIS
 
@@ -105,7 +112,7 @@ IO::Socket::Socks::Wrapper - Allow any perl module to work through a socks proxy
 
 	# only Net::FTP and Net::HTTP
 	use IO::Socket::Socks::Wrapper (
-		Net::FTP => { # `Net::FTP::dataconn' to wrap data connection
+		Net::FTP => { # use also `Net::FTP::dataconn' to wrap data connection
 			ProxyAddr => '10.0.0.1',
 			ProxyPort => 1080,
 			SocksDebug => 1
@@ -150,30 +157,67 @@ IO::Socket::Socks::Wrapper - Allow any perl module to work through a socks proxy
 
 =back
 
+=over
+
+	# more direct LWP::UserAgent wrapping
+	
+	# we need to associate LWP::Protocol::http::Socket and LWP::Protocol::https::Socket packages
+	# with socks proxy
+	# this packages haven't separate modules
+	# LWP::Protocol::http and LWP::Protocol::https modules includes this packages respectively
+	# IO::Socket::Socks::Wrapper should have access to @ISA of each package which want to be wrapped
+	# when package == module it can load packages automatically and do its magic with @ISA
+	# but in the case like this loading will fail
+	# so, we should load this modules manually
+	use LWP::Protocol::http;
+	use LWP::Protocol::https;
+	use IO::Socket::Socks::Wrapper (
+		LWP::Protocol::http::Socket => {
+			ProxyAddr => 'localhost',
+			ProxyPort => 1080,
+			SocksDebug => 1
+		},
+		LWP::Protocol::https::Socket => {
+			ProxyAddr => 'localhost',
+			ProxyPort => 1080,
+			SocksDebug => 1
+		}
+	);
+	use LWP;
+	
+	# then use lwp as usual
+	my $ua = LWP::UserAgent->new();
+	
+	# in this case Net::HTTP and Net::HTTPS objects will use direct network access
+	# but LWP::UserAgent objects will use socks proxy
+
+=back
+
 =head1 DESCRIPTION
 
 C<IO::Socket::Socks::Wrapper> allows to wrap up the network connections into socks proxy. It can wrap up connection
-from separate modules or any network connection. It works by overriding builtin connect() function in the package
+from separate packages or any network connection. It works by overriding builtin connect() function in the package
 or globally.
 
 =head1 METHODS
 
 =head2 import( CFG )
 
-import() is invoked when C<IO::Socket::Socks::Wrapper> loaded by `use'. Later it can be invoked manually
-to change proxy in some module. Global overriding will not work in modules which was loaded before calling 
+import() is invoked when C<IO::Socket::Socks::Wrapper> loaded by `use' command. Later it can be invoked manually
+to change proxy in some package. Global overriding will not work in packages which was loaded before calling 
 IO::Socket::Socks::Wrapper->import(). So, for this purposes `use IO::Socket::Socks::Wrapper' should be before
-any other uses.
+any other `use' statements.
 
-CFG syntax to wrap up separate modules is:
+CFG syntax to wrap up separate packages is:
 
-	module => $hashref,
+	pkg => $hashref,
 	...
-	module => $hashref
+	pkg => $hashref
 
-module is a module which is responsible for connections. For example if you want to wrap LWP http connections, then module
-name should be Net::HTTP, for https connections it should be Net::HTTPS. You really need to look at the code of the module
-which you want to wrap to determine name for wrapping or use global wrapping which will wrap all that can. Use `SocksDebug' to
+pkg is a package which is responsible for connections. For example if you want to wrap LWP http connections, then module
+name should be Net::HTTP, for https connections it should be Net::HTTPS or even LWP::Protocol::http::Socket and
+LWP::Protocol::https::Socket respectively (see examples above). You really need to look at the source code of the package
+which you want to wrap to determine the name for wrapping or use global wrapping which will wrap all that can. Use `SocksDebug' to
 verify that wrapping works good.
 
 For the global wrapping only $hashref should be specified.
@@ -183,7 +227,7 @@ and (Connect|Bind|Udp)Port. To disable of using proxy $hashref could be scalar w
 
 =head1 BUGS
 
-Wrapping doesn't work with impure perl modules. WWW::Curl for example.
+Wrapping doesn't work with impure perl packages. WWW::Curl for example.
 
 =head1 SEE ALSO
 
